@@ -3,6 +3,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <hildon/hildon.h>
+#include <string.h>
 #include "minimal.h"
 
 GdkImage *image;
@@ -20,7 +21,7 @@ unsigned short* screenbuffer = NULL;
 unsigned long keys = 0;
 
 int keymap[65536];
-char string [255];
+char *cfile;
 char *loadst;
 char *file;
 
@@ -108,13 +109,11 @@ window_key_proxy (GtkWidget *widget,
 			}
 			key = 0;break;
 	case 19:
-		snprintf(string,254,"%s.%s.save",file,loadst);
-		SaveState(string);
+		SaveState(cfile);
 		key = 0;break;
 	break;
 	case 20:
-		snprintf(string,254,"%s.%s.save",file,loadst);
-		LoadState(string);
+		LoadState(cfile);
 		key = 0;break;
 	break;
 	default:
@@ -134,6 +133,7 @@ window_key_proxy (GtkWidget *widget,
 void hildon_init(int *argc, char ***argv,char *fl,char* lst)
 {
 	file=fl;
+	cfile="/opt/usr/psx4m/savestate";
 	loadst=lst;
 
 	// read key config
