@@ -3,4 +3,4 @@
 extern int iSoundMuted;
 extern int linesInterlace_user;
 
-void hildon_init(int *argc, char ***argv);
+void hildon_init(int *argc, char ***argv,char *fl,char* lst);
